@@ -8,6 +8,7 @@
 #include <gsl/gsl_math.h>
 #include <gsl/gsl_cdf.h>
 #include <iostream>
+#include <random> 
 
 #include "logisticfunc.h"
 
@@ -55,6 +56,7 @@ void citconlog3pcvr( double *L, double *G, double *T, double *C, int &nrow, int
 	vector<double> permindvec;
 	gsl_matrix *cov, *X;
 	gsl_vector *Gm, *Gp, *c;
+	unsigned se = 10;
 
 	bootind = new int[nrow];
 	nposperm = new int[boots];
@@ -435,7 +437,7 @@ void citconlog3pcvr( double *L, double *G, double *T, double *C, int &nrow, int
 	npos = 0;
 	for(i = 0; i < firstloop; i++){
 		// randomly permute residuals
-		random_shuffle( gresid.begin(), gresid.end(), randwrapper3a );
+		shuffle( gresid.begin(), gresid.end(), std::default_random_engine(se) );	
 		for(rw = 0; rw < nrow; rw++) {
 			brw = bootind[ rw ];
 			aa = 1;
@@ -496,7 +498,7 @@ void citconlog3pcvr( double *L, double *G, double *T, double *C, int &nrow, int
 		while(aa && bb) {
 
 			// randomly permute residuals
-			random_shuffle( gresid.begin(), gresid.end(), randwrapper3a );
+			shuffle( gresid.begin(), gresid.end(), std::default_random_engine(se) );	
 			for(rw = 0; rw < nrow; rw++) {
 				brw = bootind[ rw ];
 				aa = 1;
